@@ -35,6 +35,7 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-debug.h>
+#include <eel/eel-vfs-extensions.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
@@ -256,6 +257,7 @@ char *
 nautilus_compute_title_for_location (GFile *location)
 {
 	NautilusFile *file;
+        GMount *mount;
 	char *title;
 
 	/* TODO-gio: This doesn't really work all that great if the
@@ -264,6 +266,14 @@ nautilus_compute_title_for_location (GFile *location)
 	if (nautilus_is_home_directory (location)) {
 		return g_strdup (_("Home"));
 	}
+
+        if ((mount = nautilus_get_mounted_mount_for_root (location)) != NULL) {
+                title = g_mount_get_name(mount);
+
+                g_object_unref(mount);
+
+                return title;
+        }
 	
 	title = NULL;
 	if (location) {
@@ -523,6 +533,15 @@ nautilus_is_desktop_directory (GFile *dir)
 	return g_file_equal (dir, desktop_dir);
 }
 
+gboolean
+nautilus_is_search_directory (GFile *dir)
+{
+        g_autofree gchar *uri = NULL;
+
+        uri = g_file_get_uri (dir);
+        return eel_uri_is_search (uri);
+}
+
 GMount *
 nautilus_get_mounted_mount_for_root (GFile *location)
 {
