@@ -86,7 +86,7 @@ struct _NautilusPathBarDetails {
 	GtkWidget *up_slider_button;
 	GtkWidget *down_slider_button;
 	guint settings_signal_id;
-	gint16 slider_width;
+	gint slider_width;
 	guint timer;
 	guint slider_visible : 1;
 	guint need_timer : 1;
@@ -311,8 +311,12 @@ nautilus_path_bar_init (NautilusPathBar *path_bar)
 	gtk_widget_set_has_window (GTK_WIDGET (path_bar), FALSE);
         gtk_widget_set_redraw_on_allocate (GTK_WIDGET (path_bar), FALSE);
 
-        path_bar->priv->up_slider_button = get_slider_button (path_bar, "go-previous-symbolic");
-        path_bar->priv->down_slider_button = get_slider_button (path_bar, "go-next-symbolic");
+        path_bar->priv->up_slider_button = get_slider_button (path_bar, "pan-start-symbolic");
+        path_bar->priv->down_slider_button = get_slider_button (path_bar, "pan-end-symbolic");
+        gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (path_bar->priv->up_slider_button)),
+                                     "slider-button");
+        gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (path_bar->priv->down_slider_button)),
+                                     "slider-button");
 
         g_signal_connect_swapped (path_bar->priv->up_slider_button, "clicked", G_CALLBACK (nautilus_path_bar_scroll_up), path_bar);
         g_signal_connect_swapped (path_bar->priv->down_slider_button, "clicked", G_CALLBACK (nautilus_path_bar_scroll_down), path_bar);
@@ -638,6 +642,9 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
                 return;
 	}
         direction = gtk_widget_get_direction (widget);
+	gtk_widget_get_preferred_width (path_bar->priv->up_slider_button,
+					&path_bar->priv->slider_width,
+					NULL);
 
   	/* First, we check to see if we need the scrollbars. */
 	width = 0;
