@@ -65,7 +65,8 @@ open_location_cb (NautilusPlacesView *view,
 
         switch (open_flags) {
         case GTK_PLACES_OPEN_NEW_TAB:
-                flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+                flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB |
+                        NAUTILUS_WINDOW_OPEN_FLAG_DONT_MAKE_ACTIVE;
                 break;
 
         case GTK_PLACES_OPEN_NEW_WINDOW:
@@ -102,6 +103,29 @@ loading_cb (NautilusView *view)
         g_object_notify (G_OBJECT (view), "is-loading");
 }
 
+static void
+show_error_message_cb (NautilusGtkPlacesView *view,
+                       const gchar           *primary,
+                       const gchar           *secondary)
+{
+        GtkWidget *dialog;
+        GtkWidget *window;
+
+        window = gtk_widget_get_toplevel (GTK_WIDGET (view));
+
+        dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                                         GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+                                         GTK_MESSAGE_ERROR,
+                                         GTK_BUTTONS_CLOSE,
+                                         "%s", primary);
+        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                                  "%s", secondary);
+
+        gtk_dialog_run (GTK_DIALOG (dialog));
+
+        gtk_widget_destroy (dialog);
+}
+
 static void
 nautilus_places_view_finalize (GObject *object)
 {
@@ -203,7 +227,7 @@ nautilus_places_view_set_location (NautilusView *view,
                  * delegates the location to application, which takes care of
                  * selecting the appropriate view.
                  */
-                if (!g_strcmp0 (uri, "other-locations:///") == 0) {
+                if (g_strcmp0 (uri, "other-locations:///") != 0) {
                         nautilus_application_open_location_full (NAUTILUS_APPLICATION (g_application_get_default ()),
                                                                  location, 0, NULL, NULL, NULL);
                 } else {
@@ -347,6 +371,11 @@ nautilus_places_view_init (NautilusPlacesView *self)
                                   G_CALLBACK (open_location_cb),
                                   self);
 
+        g_signal_connect_swapped (priv->places_view,
+                                  "show-error-message",
+                                  G_CALLBACK (show_error_message_cb),
+                                  self);
+
 }
 
 NautilusPlacesView *
